@@ -28,6 +28,8 @@ object_new->scale = object->scale;
 void gamgi_engine_copy_out_text (gamgi_text *text, gamgi_text *text_new)
 {
 static_copy (GAMGI_CAST_OBJECT text, GAMGI_CAST_OBJECT text_new);
+text_new->draw = text->draw;
+text_new->mark = text->mark;
 
 /**********************************
  * safe programming: text->string *
@@ -69,8 +71,6 @@ text_new->quaternion[3] = text->quaternion[3];
 text_new->red = text->red;
 text_new->green = text->green;
 text_new->blue = text->blue;
-
-text_new->draw = text->draw;
 }
 
 void gamgi_engine_copy_out_orbital (gamgi_orbital *orbital, gamgi_orbital *orbital_new)
@@ -114,11 +114,8 @@ bond_new->dlist2 = NULL;
 void gamgi_engine_copy_out_atom (gamgi_atom *atom, gamgi_atom *atom_new)
 {
 static_copy (GAMGI_CAST_OBJECT atom, GAMGI_CAST_OBJECT atom_new);
-
 atom_new->draw = atom->draw;
 atom_new->mark = atom->mark;
-atom_new->size = atom->size;
-atom_new->variancy = atom->variancy;
 
 atom_new->element = atom->element;
 atom_new->mass = atom->mass;
@@ -131,6 +128,13 @@ atom_new->position[0] = atom->position[0];
 atom_new->position[1] = atom->position[1];
 atom_new->position[2] = atom->position[2];
 
+/*************
+ * view data *
+ *************/
+
+atom_new->size = atom->size;
+atom_new->variancy = atom->variancy;
+
 atom_new->red = atom->red;
 atom_new->green = atom->green;
 atom_new->blue = atom->blue;
@@ -298,6 +302,7 @@ int i;
 static_copy (GAMGI_CAST_OBJECT group, GAMGI_CAST_OBJECT group_new);
 group_new->draw = group->draw;
 group_new->type = group->type;
+group_new->mark = group->mark;
 
 group_new->atom = group->atom;
 group_new->element = group->element;
@@ -346,12 +351,11 @@ while (i-- > 0) group_new->loops[i] = group->loops[i];
 group_new->n_points = group->n_points;
 group_new->n_loops = group->n_loops;
 
-/*********************
- * copy faces, color *
- *********************/
+/******************
+ * copy view data *
+ ******************/
 
 group_new->faces = group->faces;
-
 group_new->red = group->red;
 group_new->green = group->green;
 group_new->blue = group->blue;
@@ -386,6 +390,7 @@ int i;
 
 static_copy (GAMGI_CAST_OBJECT cluster, GAMGI_CAST_OBJECT cluster_new);
 cluster_new->type = cluster->type;
+cluster_new->mark = cluster->mark;
 
 /**************************************
  * copy position and orientation data *
@@ -438,9 +443,9 @@ cluster_new->n_colors = cluster->n_colors;
 cluster_new->n_paints = cluster->n_paints;
 cluster_new->n_dots = cluster->n_dots;
 
-/************************
- * copy hide/show flags *
- ************************/
+/*************
+ * View data *
+ *************/
 
 cluster_new->faces = cluster->faces;
 cluster_new->dots = cluster->dots;
@@ -597,8 +602,8 @@ graph_new->draw = graph->draw;
 void gamgi_engine_copy_out_assembly (gamgi_assembly *assembly, gamgi_assembly *assembly_new)
 {
 static_copy (GAMGI_CAST_OBJECT assembly, GAMGI_CAST_OBJECT assembly_new);
-
 assembly_new->draw = assembly->draw;
+assembly_new->mark = assembly->mark;
 
 /**************************************
  * copy position and orientation data *
