@@ -58,6 +58,9 @@ text->object.number = gamgi_engine_number_text_get ();
  * initialise text *
  *******************/
 
+text->draw = NULL;
+text->mark = 0;
+
 text->origin[0] = 0.0;
 text->origin[1] = 0.0;
 text->origin[2] = 0.0;
@@ -76,8 +79,6 @@ text->length = 0;
 
 text->style = FALSE;
 text->font = FALSE;
-
-text->draw = NULL;
 }
 
 /******* external function *****
@@ -314,6 +315,7 @@ group->object.number = gamgi_engine_number_group_get ();
  * initialise group *
  ********************/
 
+group->mark = 0;
 group->atom = -1;
 group->element = -1;
 group->number = 0;
@@ -406,6 +408,9 @@ cluster->object.number = gamgi_engine_number_cluster_get ();
  * initialise cluster *
  **********************/
 
+cluster->type = FALSE;
+cluster->mark = 0;
+
 cluster->origin[0] = 0.0;
 cluster->origin[1] = 0.0;
 cluster->origin[2] = 0.0;
@@ -419,8 +424,6 @@ cluster->quaternion[1] = 0.0;
 cluster->quaternion[2] = 0.0;
 cluster->quaternion[3] = 1.0;
 
-cluster->type = FALSE;
-
 cluster->points = NULL;
 cluster->loops = NULL;
 cluster->colors = NULL;
@@ -608,6 +611,9 @@ assembly->object.number = gamgi_engine_number_assembly_get ();
  * initialise assembly *
  ***********************/
 
+assembly->draw = NULL;
+assembly->mark = 0;
+
 assembly->origin[0] = 0.0;
 assembly->origin[1] = 0.0;
 assembly->origin[2] = 0.0;
@@ -620,8 +626,6 @@ assembly->quaternion[0] = 0.0;
 assembly->quaternion[1] = 0.0;
 assembly->quaternion[2] = 0.0;
 assembly->quaternion[3] = 1.0;
-
-assembly->draw = NULL;
 }
 
 /***** external function *****
