@@ -28,7 +28,7 @@ static int static_start (FILE *fp, char *string, int depth, gamgi_bool *error);
 void gamgi_expat_export_cdata (FILE *fp,
 char *string, int depth, int *column, gamgi_bool *error);
 
-int gamgi_expat_export_attribute (FILE *fp,
+void gamgi_expat_export_attribute (FILE *fp,
 char *string, int depth, int *column, gamgi_bool *error);
 
 void gamgi_expat_export_element (FILE *fp, char *element,
@@ -63,7 +63,7 @@ int *depth_last, gamgi_bool *error);
 static void static_config_help (gamgi_window *window,
 FILE *fp, int depth_parent, int *depth_last, gamgi_bool *error);
 
-static void static_config_text (gamgi_window *window,
+static void static_config_text (gamgi_window *window, 
 FILE *fp, int depth_parent, int *depth_last, gamgi_bool *error);
 
 static void static_config_orbital (gamgi_window *window,
@@ -117,86 +117,148 @@ FILE *fp, int depth_parent, int *depth_last, gamgi_bool *error);
 static void static_config_gamgi (gamgi_window *window,
 FILE *fp, int depth_parent, int *depth_last, gamgi_bool *error);
 
-static void static_config (gamgi_window *window, FILE *fp,
+static void static_config (gamgi_window *window, FILE *fp, 
 int depth_parent, int *depth_last, gamgi_bool *error);
 
+static void static_bond_add (gamgi_object *parent, gamgi_bond *bond);
+
+static void static_bond_parent (gamgi_bond *bond, gamgi_window *window,
+gamgi_object *scope, int *id, gamgi_bool *error);
+
 static void static_object_text (gamgi_text *text, 
 gamgi_window *window, FILE *fp, int depth_parent, 
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_object_orbital (gamgi_orbital *orbital,
-gamgi_window *window, FILE *fp, int depth_parent,
+static void static_object_orbital (gamgi_orbital *orbital, 
+gamgi_window *window, FILE *fp, int depth_parent, 
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_object_bond (gamgi_bond *bond,
-gamgi_window *window, FILE *fp, int depth_parent,
+static void static_object_bond (gamgi_bond *bond, 
+gamgi_window *window, FILE *fp, int depth_parent, 
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_bond_add (gamgi_object *parent, gamgi_bond *bond);
+static void static_object_atom (gamgi_atom *atom, gamgi_window *window,
+gamgi_object *scope, FILE *fp, int depth_parent, int *depth_last, int *id,
+gamgi_bool *error);
 
-static void static_bond_parent (gamgi_bond *bond, 
-gamgi_window *window, int *id);
-
-static void static_object_atom (gamgi_atom *atom,
-gamgi_window *window, FILE *fp, int depth_parent,
+static void static_object_direction (gamgi_direction *direction, 
+gamgi_window *window, FILE *fp, int depth_parent, 
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_object_direction (gamgi_direction *direction,
-gamgi_window *window, FILE *fp, int depth_parent,
+static void static_object_plane (gamgi_plane *plane, 
+gamgi_window *window, FILE *fp, int depth_parent, 
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_object_plane (gamgi_plane *plane,
-gamgi_window *window, FILE *fp, int depth_parent,
+static void static_object_group (gamgi_group *group, 
+gamgi_window *window, FILE *fp, int depth_parent, 
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_object_group (gamgi_group *group,
-gamgi_window *window, FILE *fp, int depth_parent,
+static void static_object_molecule (gamgi_molecule *molecule, 
+gamgi_window *window, FILE *fp, int depth_parent, 
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_object_molecule (gamgi_molecule *molecule,
-gamgi_window *window, FILE *fp, int depth_parent,
+static void static_object_cluster (gamgi_cluster *cluster, 
+gamgi_window *window, FILE *fp, int depth_parent, 
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_object_cluster (gamgi_cluster *cluster,
-gamgi_window *window, FILE *fp, int depth_parent,
+static void static_object_cell (gamgi_cell *cell, 
+gamgi_window *window, FILE *fp, int depth_parent, 
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_object_cell (gamgi_cell *cell,
-gamgi_window *window, FILE *fp, int depth_parent,
+static void static_object_arrow (gamgi_arrow *arrow, 
+gamgi_window *window, FILE *fp, int depth_parent, 
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_object_arrow (gamgi_arrow *arrow,
-gamgi_window *window, FILE *fp, int depth_parent,
+static void static_object_shape (gamgi_shape *shape, 
+gamgi_window *window, FILE *fp, int depth_parent, 
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_object_shape (gamgi_shape *shape,
-gamgi_window *window, FILE *fp, int depth_parent,
+static void static_object_graph (gamgi_graph *graph, 
+gamgi_window *window, FILE *fp, int depth_parent, 
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_object_graph (gamgi_graph *graph,
-gamgi_window *window, FILE *fp, int depth_parent,
+static void static_object_assembly (gamgi_assembly *assembly, 
+gamgi_window *window, FILE *fp, int depth_parent, 
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_object_assembly (gamgi_assembly *assembly,
-gamgi_window *window, FILE *fp, int depth_parent,
+static void static_object_light (gamgi_light *light, 
+gamgi_window *window, FILE *fp, int depth_parent, 
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_object_light (gamgi_light *light,
-gamgi_window *window, FILE *fp, int depth_parent,
+static void static_object_layer (gamgi_layer *layer, 
+gamgi_window *window, FILE *fp, int depth_parent, 
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_object_layer (gamgi_layer *layer,
-gamgi_window *window, FILE *fp, int depth_parent,
+static void static_object_window (gamgi_window *window, FILE *fp, 
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_bond_atom (gamgi_atom *atom, gamgi_window *window,
+FILE *fp, int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_bond_id (gamgi_bond *bond, gamgi_window *window,
+FILE *fp, int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_bond_single (gamgi_bond *bond, gamgi_window *window,
+FILE *fp, int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_text_list (gamgi_window *window, FILE *fp,
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_orbital_list (gamgi_window *window, FILE *fp, 
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_bond_list (gamgi_window *window, FILE *fp,
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_atom_list (gamgi_window *window, FILE *fp,
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_direction_list (gamgi_window *window, FILE *fp,
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_plane_list (gamgi_window *window, FILE *fp,
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_group_list (gamgi_window *window, FILE *fp,
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_molecule_list (gamgi_window *window, FILE *fp,
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_cluster_list (gamgi_window *window, FILE *fp,
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_cell_list (gamgi_window *window, FILE *fp,
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_arrow_list (gamgi_window *window, FILE *fp,
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_shape_list (gamgi_window *window, FILE *fp,
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_graph_list (gamgi_window *window, FILE *fp,
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_assembly_list (gamgi_window *window, FILE *fp,
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_light_list (gamgi_window *window, FILE *fp,
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_layer_list (gamgi_window *window, FILE *fp,
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object_window_list (FILE *fp, int depth_parent,
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_object_window (gamgi_window *window, 
-FILE *fp, int depth_parent, int *depth_last, 
-int *id, gamgi_bool *error);
-
-static void static_object_gamgi (FILE *fp, int depth_parent, 
+static void static_object_gamgi_list (FILE *fp, int depth_parent,
 int *depth_last, int *id, gamgi_bool *error);
 
-static void static_object (gamgi_window *window, FILE *fp,
+void static_object_list (gamgi_window *window, FILE *fp,
+int depth_parent, int *depth_last, int *id, gamgi_bool *error);
+
+static void static_object (gamgi_window *window, FILE *fp, 
 int depth_parent, int *depth_last, gamgi_bool *error);
 
 static void static_header_xml (FILE *fp, gamgi_bool *error);
@@ -205,7 +267,7 @@ static void static_header_gml (FILE *fp, gamgi_bool *error);
 
 static void static_header_x3d (FILE *fp, gamgi_bool *error);
 
- **********************
+**********************
  * external functions *
  **********************/
 
@@ -221,7 +283,7 @@ void gamgi_expat_export_x3d (FILE *fp, gamgi_window *window, gamgi_bool *error);
  * Rationale *
  *************
 
-Under development.
+Last update (lists of objects): July 2011.
 
  *************
  * Rationale *
