@@ -410,11 +410,11 @@ char token[GAMGI_ENGINE_TOKEN];
  * id (optional, required if bonded) *
  *************************************/
 
-if (GAMGI_EXPAT_ID_ATOM == TRUE || atom->mark == TRUE)
+if (GAMGI_EXPAT_ID_ATOM == TRUE || atom->mark > 0)
   {
   sprintf (string, "id=\"%d\"", (*id)++);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
-  atom->mark = FALSE;
+  atom->mark = 0;
   }
 
 /*******************
