@@ -40,6 +40,7 @@
 #include "gamgi_phys_plane.h"
 #include "gamgi_phys_direction.h"
 #include "gamgi_phys_projection.h"
+#include "gamgi_phys_reciprocal.h"
 #include "gamgi_io_token.h" 
 #include "gamgi_io_file.h"
 #include "gamgi_expat_import.h"
@@ -247,7 +248,7 @@ if (object->object != NULL)
 free (gml);
 }
 
-static void static_apply_config (void)
+static void static_config (gamgi_gml *gml)
 {
 gamgi_object *object, *object_old;
 gamgi_atom_class *atom;
@@ -434,31 +435,24 @@ if (object->object != NULL)
   }
 }
 
-static void static_apply_object (gamgi_gml *gml)
+static void static_object (gamgi_gml *gml)
 {
 gamgi_window *window;
 gamgi_layer *layer;
 gamgi_cell *cell;
 gamgi_plane *plane;
 gamgi_direction *direction;
-gamgi_atom *atom1, *atom2, *atom3;
 gamgi_object *object;
-gamgi_dlist *dlist, *dlist_a;
-double rotation[9], relative[9], absolute[9];
-double zero[3], translation[3], origin[3], euler[3];
-gamgi_enum class;
+gamgi_dlist *dlist;
 
 /******************************
  * first object is <gml>, so  *
  * we start with the next one *
  ******************************/
 
-dlist = gml->object_start->next;
-while (dlist != NULL)
+for (dlist = gml->object_start->next; dlist != NULL; dlist = dlist->next)
   {
-  object = dlist->data;
-  class = object->class;
-
+  object = GAMGI_CAST_OBJECT dlist->data;
   switch (object->class)
     {
     /************************************************************
@@ -489,115 +483,42 @@ while (dlist != NULL)
     break;
 
     case GAMGI_ENGINE_PLANE:
+    gamgi_engine_link_object_object (object, object->object);
     plane = GAMGI_CAST_PLANE object;
     if (plane->reference == GAMGI_ENGINE_CELL)
       {
-      /************************************
-       * this is a crystallographic plane *
-       ************************************/
+      /**************************
+       * crystallographic plane *
+       **************************/
 
-      /**************************************************
-       * restore origin and quaternion after being used *
-       * to store x,y,z and e1,e2,e3 data. by default   *
-       * origin is 0,0,0 and quaternion is 0,0,0,1 and  *
-       * the fourth quaternion coordinate was not used  *
-       **************************************************/
-
-      gamgi_math_vector_copy (plane->origin, origin);
-      gamgi_math_vector_zero (plane->origin);
-      gamgi_math_vector_copy (plane->quaternion, euler);
-      gamgi_math_vector_zero (plane->quaternion);
- 
       cell = GAMGI_CAST_CELL object->object;
       if (cell->type == GAMGI_PHYS_PROJECTION)
         {
-        if (plane->type == FALSE) plane->type = GAMGI_PHYS_POLE;
         gamgi_phys_projection_create (plane->type, &plane->points, 
         &plane->n_points, &plane->loops, &plane->n_loops);
-        }
-      else
-        {
-        gamgi_phys_plane_cell (plane, cell);
-        }
-
-      /*********************************
-       * link projection plane to cell *
-       * before building pole,trace    *
-       *********************************/
-
-      gamgi_engine_link_plane_cell (plane, cell);
-      if (cell->type == GAMGI_PHYS_PROJECTION)
         gamgi_mesa_rotate_out_plane (plane, NULL, NULL, NULL);
-
-      /*****************************
-       * set position, orientation *
-       *****************************/
-
-      gamgi_math_position_plane_rotation_set (plane, euler);
-      gamgi_math_position_plane_translation_set (plane, origin);
-      }
-    else if (plane->reference == GAMGI_ENGINE_ATOM)
-      {
-      /****************************************
-       * this is an atomic plane: link the    *
-       * atoms and later on build the polygon *
-       ****************************************/
-
-      gamgi_engine_link_object_object (object, object->object);
+        }
+      if (plane->type == GAMGI_PHYS_VECTOR)
+        gamgi_phys_reciprocal_points (plane);
       }
     break;
 
     case GAMGI_ENGINE_DIRECTION:
+    gamgi_engine_link_object_object (object, object->object);
     direction = GAMGI_CAST_DIRECTION object;
     if (direction->reference == GAMGI_ENGINE_CELL)
       {
-      /****************************************
-       * this is a crystallographic direction *
-       ****************************************/
-
-      /**************************************************
-       * restore origin and quaternion after being used *
-       * to store x,y,z and e1,e2,e3 data. by default   *
-       * origin is 0,0,0 and quaternion is 0,0,0,1 and  *
-       * the fourth quaternion coordinate was not used  *
-       **************************************************/
-
-      gamgi_math_vector_copy (direction->origin, origin);
-      gamgi_math_vector_zero (direction->origin);
-      gamgi_math_vector_copy (direction->quaternion, euler);
-      gamgi_math_vector_zero (direction->quaternion);
+      /******************************
+       * crystallographic direction *
+       ******************************/
 
       cell = GAMGI_CAST_CELL object->object;
       if (cell->type == GAMGI_PHYS_PROJECTION)
         {
-        if (direction->type == FALSE) direction->type = GAMGI_PHYS_POLE;
         gamgi_phys_projection_create (direction->type, &direction->points, 
         &direction->n_points, &direction->loops, &direction->n_loops);
-        }
-      else
-        {
-        gamgi_phys_direction_cell (direction, cell);
-        }
-
-      gamgi_engine_link_direction_cell (direction, cell);
-      if (cell->type == GAMGI_PHYS_PROJECTION)
         gamgi_mesa_rotate_out_direction (direction, NULL, NULL, NULL);
-
-      /*****************************
-       * set position, orientation *
-       *****************************/
-
-      gamgi_math_position_direction_rotation_set (direction, euler);
-      gamgi_math_position_direction_translation_set (direction, origin);
-      }
-    else if (direction->reference == GAMGI_ENGINE_ATOM)
-      {
-      /*****************************************
-       * this is an atomic direction: link the *
-       * atoms and later on build the line     *
-       *****************************************/
-
-      gamgi_engine_link_object_object (object, object->object);
+        }
       }
     break;
 
@@ -605,143 +526,6 @@ while (dlist != NULL)
     gamgi_engine_link_object_object (object, object->object);
     break;
     }
-
-  dlist = dlist->next;
-  }
-
-/******************************
- * first object is <gml>, so  *
- * we start with the next one *
- ******************************/
-
-for (dlist = gml->object_start->next; dlist != NULL; dlist = dlist->next)
-  {
-  object = GAMGI_CAST_OBJECT dlist->data;
-  switch (object->class)
-    {
-    case GAMGI_ENGINE_PLANE:
-    plane = GAMGI_CAST_PLANE object;
-    if (plane->reference == GAMGI_ENGINE_ATOM)
-      {
-      /*********************************************************
-       * atomic plane: the first three are the reference atoms *
-       *                                                       *
-       * the plane type is needed because of the rotation next *
-       *********************************************************/
-
-      dlist_a = plane->atom_start;
-      atom1 = GAMGI_CAST_ATOM dlist_a->data;
-      dlist_a = dlist_a->next;
-      atom2 = GAMGI_CAST_ATOM dlist_a->data;
-      dlist_a = dlist_a->next;
-      atom3 = GAMGI_CAST_ATOM dlist_a->data;
-      plane->type = GAMGI_PHYS_POLYGON;
-
-      /*******************************************************
-       * 1) Get origin and euler data that was temporarily   *
-       * stored in plane->origin and plane->quaternion.      *
-       * The fourth quaternion coordinate was not used       *
-       * 2) Get absolute origin and quaternion for plane.    *
-       * 3) Rotate and translate backward the plane, to its  *
-       * zero coordinates. 4) Rotate and translate backward  *
-       * the parent to its sero coordinates. 5) create the   *
-       * plane. 6) Rotate and translate forward the parent   *
-       * to its current coordinates. 7) Rotate and translate *
-       * forward the plane to its current coordinates.       *
-       *******************************************************/
-
-      gamgi_math_position_rotation (plane->object.object, rotation);
-      gamgi_math_vector_copy (plane->quaternion, euler);
-      gamgi_math_euler_to_matrix (euler, relative);
-      gamgi_math_matrix_matrix (relative, rotation, absolute);
-      gamgi_math_quaternion_from_matrix (absolute, plane->quaternion);
-
-      gamgi_math_position_translation (plane->object.object, translation);
-      gamgi_math_vector_copy (plane->origin, origin);
-      gamgi_math_vector_add (origin, translation, plane->origin);
-
-      gamgi_math_vector_zero (zero);
-      gamgi_math_position_plane_rotation_set (plane, zero);
-      gamgi_math_position_plane_translation_set (plane, zero);
-
-      /*********************************************
-       * get list of plane atoms and build polygon *
-       *********************************************/
-
-      dlist_a = gamgi_engine_dlist_atom_object (object, NULL);
-      gamgi_phys_plane_atoms (plane, atom1, atom2, atom3, dlist_a, FALSE);
-
-      /*****************************
-       * set position, orientation *
-       *****************************/
-
-      gamgi_math_position_plane_rotation_set (plane, euler);
-      gamgi_math_position_plane_translation_set (plane, origin);
-      }
-    break;
-
-    case GAMGI_ENGINE_DIRECTION:
-    direction = GAMGI_CAST_DIRECTION object;
-    if (direction->reference == GAMGI_ENGINE_ATOM)
-      {
-      /*************************************************************
-       * atomic direction: the first two are the reference atoms   *
-       *                                                           *
-       * the direction type is needed because of the rotation next *
-       *************************************************************/
-
-      dlist_a = direction->atom_start;
-      atom1 = GAMGI_CAST_ATOM dlist_a->data;
-      dlist_a = dlist_a->next;
-      atom2 = GAMGI_CAST_ATOM dlist_a->data;
-      direction->type = GAMGI_PHYS_LINE;
-
-      /**********************************************************
-       * 1) Get origin and euler data that was temporarily      *
-       * stored in direction->origin and direction->quaternion. *
-       * The fourth quaternion coordinate was not used          *
-       * 2) Get absolute origin and quaternion for direction.   *
-       * 3) Rotate and translate backward the direction, to its *
-       * zero coordinates. 4) Rotate and translate backward     *
-       * the parent to its sero coordinates. 5) create the      *
-       * direction. 6) Rotate and translate forward the parent  *
-       * to its current coordinates. 7) Rotate and translate    *
-       * forward the direction to its current coordinates.      *
-       **********************************************************/
-
-      gamgi_math_position_rotation (direction->object.object, rotation);
-      gamgi_math_vector_copy (direction->quaternion, euler);
-      gamgi_math_euler_to_matrix (euler, relative);
-      gamgi_math_matrix_matrix (relative, rotation, absolute);
-      gamgi_math_quaternion_from_matrix (absolute, direction->quaternion);
-
-      gamgi_math_position_translation (direction->object.object, translation);
-      gamgi_math_vector_copy (direction->origin, origin);
-      gamgi_math_vector_add (origin, translation, direction->origin);
-
-      gamgi_math_vector_zero (zero);
-      gamgi_math_position_direction_rotation_set (direction, zero);
-      gamgi_math_position_direction_translation_set (direction, zero);
-
-      /**********************************************
-       * get list of direction atoms and build line *
-       **********************************************/
-
-      dlist_a = gamgi_engine_dlist_atom_object (object, NULL);
-      gamgi_phys_direction_atoms (direction, atom1, atom2, dlist_a, FALSE);
-
-      /*****************************
-       * set position, orientation *
-       *****************************/
-
-      gamgi_math_position_direction_rotation_set (direction, euler);
-      gamgi_math_position_direction_translation_set (direction, origin);
-      }
-    break;
-
-    default:
-    break;
-    }
   }
 
 /************************************************************
@@ -823,7 +607,7 @@ else if (public_id != NULL && strcmp (public_id, GAMGI_IO_HTML_PUBLIC) != 0)
   }
 }
 
-static void static_cdata_gml (void *data, 
+static void static_cdata_ml (void *data, 
 const char *cdata, int length)
 {
 gamgi_ml *ml = GAMGI_CAST_ML data;
@@ -855,12 +639,12 @@ fileline = XML_GetCurrentLineNumber (ml->parser);
  * than GAMGI_ENGINE_LINE.                         *
  ***************************************************/ 
 
-if (++length > GAMGI_ENGINE_LINE)
+if (length + 1 > GAMGI_ENGINE_LINE)
   ml->valid = gamgi_io_error_cdata (ml->filename, 
   fileline, ml->window);
 else
   {
-  gamgi_io_token_cut (cdata, line, length);
+  gamgi_io_token_cut (cdata, line, length + 1);
 
   /***********************************
    * Only delimiter char (by default *
@@ -875,10 +659,92 @@ else
 
 }
 
+static void static_cdata_gml (void *data,
+const char *cdata, int length)
+{
+gamgi_gml *gml = GAMGI_CAST_GML data;
+char *token, *string;
+double dvalue;
+float fvalue;
+int ivalue;
+int n, fileline;
+
+/******************************************
+ * used only in error messages: file line *
+ * indicates where current cdata starts   *
+ ******************************************/
+
+fileline = XML_GetCurrentLineNumber (gml->ml.parser);
+
+/*******************************************************
+ * For most elements, only delimiter char (defined by  *
+ * GAMGI_IO_DELIMITERS) are allowed as character data. *
+ *******************************************************/
+
+if (gml->type == FALSE)
+  { static_cdata_ml (data, cdata, length); return; }
+
+/*******************************************************************
+ * Character data in Expat is handled like this:                   *
+ * 1) when cdata continues, cdata[length] == '\0'                  *
+ * 2) when cdata ends and a element starts, cdata[length] == '<'   *
+ * 3) when cdata ends and a new line starts cdata[length] == '\n'  *
+ * in cases 2 and 3, a new callback is issued, reporting only a    *
+ * end of line. In Linux, length = 1, and cdata[length - 1] = '\n' *
+ *                                                                 *
+ * The whole strategy is: concatenate line until a end             *
+ * of line is found, then parse the line and restart again         *
+ *                                                                 *
+ * To catch ends of line, looking for Char 10 (Linux), Char 13     *
+ * (Mac OS X) or Char 10 + Char 13 (Windows) should be enough      *
+ *                                                                 *
+ * Make sure there is space to end line with a '\0' character      *
+ *******************************************************************/
+
+if (gml->used + length + 1 > GAMGI_ENGINE_LINE)
+  { gml->ml.valid = gamgi_io_error_cdata (gml->ml.filename,
+  fileline, gml->ml.window); return; }
+
+strncpy (gml->line + gml->used, cdata, length);
+gml->used += length;
+
+if (cdata[length - 1] != 10 && cdata[length - 1] != 13) return;
+
+/*********************************************
+ * parse line looking for tokens that can be *
+ * converted into doubles, floats or ints    *
+ *********************************************/
+
+gml->line[gml->used] = '\0';
+
+for (string = gml->line; (token = strtok (string, GAMGI_IO_DELIMITERS)) != NULL; string = NULL)
+  {
+  if (gml->count == gml->size)
+    { gml->ml.valid = gamgi_io_error_incompatible (gml->ml.filename,
+    fileline, gml->ml.window); return; }
+
+  n = 0;
+  if (gml->type == GAMGI_EXPAT_DOUBLE) n = sscanf (token, "%lf", &dvalue);
+  if (gml->type == GAMGI_EXPAT_FLOAT) n = sscanf (token, "%f", &fvalue);
+  if (gml->type == GAMGI_EXPAT_INT) n = sscanf (token, "%d", &ivalue);
+
+  if (n != 1) { gml->ml.valid = gamgi_io_error_cdata (gml->ml.filename,
+  fileline, gml->ml.window); return; }
+
+  if (gml->type == GAMGI_EXPAT_DOUBLE) ((double *) gml->array)[gml->count] = dvalue;
+  if (gml->type == GAMGI_EXPAT_FLOAT) ((float *) gml->array)[gml->count] = fvalue;
+  if (gml->type == GAMGI_EXPAT_INT) ((int *) gml->array)[gml->count] = ivalue;
+
+  gml->count += 1;
+  }
+
+gml->used = 0;
+}
+
 static void static_cdata_html (void *data, 
 const char *cdata, int length)
 {
-gamgi_html *html = (gamgi_html *) data;
+gamgi_html *html = GAMGI_CAST_HTML data;
 gamgi_enum parent;
 int i, fileline;
 char character;
@@ -900,7 +766,7 @@ parent = GAMGI_POINTER_TO_INT (html->ml.parent->data);
 if (parent == GAMGI_EXPAT_HTML || parent == GAMGI_EXPAT_HEAD ||
 parent == GAMGI_EXPAT_LINK || parent == GAMGI_EXPAT_UL ||
 parent == GAMGI_EXPAT_OL || parent == GAMGI_EXPAT_BR)
-  static_cdata_gml (data, cdata, length);
+  { static_cdata_ml (data, cdata, length); return; }
 
 /*****************************************************
  * insert data, line by line instead of char by char *
@@ -1347,8 +1213,6 @@ ml->filename, fileline, ml->window);
 return ml->valid;
 }
 
-
-
 static void static_create_ml (gamgi_ml *ml,
 XML_Parser parser, gamgi_window *window)
 {
@@ -1379,8 +1243,11 @@ gml->ref_object = NULL;
 gml->ref_used = 0;
 gml->ref_total = 0;
 
-gml->planes = 0;
-gml->directions = 0;
+gml->type = FALSE;
+gml->array = NULL;
+gml->size = 0;
+gml->count = 0;
+gml->used = 0;
 
 gml->ref_line = NULL;
 gml->ref_file = NULL;
@@ -1427,120 +1294,62 @@ html->preserve = FALSE;
 return html;
 }
 
-gamgi_bool gamgi_expat_import_atom (gamgi_atom *atom,
-char *filename, int fileline, gamgi_gml *gml)
-{
-gamgi_plane *plane;
-gamgi_direction *direction;
-gamgi_object *parent = atom->object.object;
-
-/**************************************
- * 1) add atoms defining planes       *
- * 2) check if atoms define a polygon *
- * 3) decrease undefined planes       *
- **************************************/
-
-if (parent->class == GAMGI_ENGINE_PLANE)
-  {
-  plane = GAMGI_CAST_PLANE parent;
-  if (plane->reference == GAMGI_ENGINE_ATOM)
-    {
-    if (plane->atoms[0] == NULL)
-      plane->atoms[0] = atom;
-    else if (plane->atoms[1] == NULL)
-      plane->atoms[1] = atom;
-    else if (plane->atoms[2] == NULL)
-      {
-      plane->atoms[2] = atom;
-      if (gamgi_phys_plane_polygon (plane->atoms[0],
-      plane->atoms[1], plane->atoms[2]) == FALSE)
-        return gamgi_io_error_child (filename, fileline, gml->ml.window);
-      gml->planes -= 1;
-      }
-    }
-  }
-
-
-/************************************
- * 1) add atoms defining directions *
- * 2) check if atoms define a line  *
- * 3) decrease undefined directions *
- ************************************/
-
-if (parent->class == GAMGI_ENGINE_DIRECTION)
-  {
-  direction = GAMGI_CAST_DIRECTION parent;
-  if (direction->reference == GAMGI_ENGINE_ATOM)
-    {
-    if (direction->atoms[0] == NULL)
-      direction->atoms[0] = atom;
-    else if (direction->atoms[1] == NULL)
-      {
-      direction->atoms[1] = atom;
-      if (gamgi_phys_direction_line (direction->atoms[0],
-      direction->atoms[1]) == FALSE)
-        return gamgi_io_error_child (filename, fileline, gml->ml.window);
-      gml->directions -= 1;
-      }
-    }
-  }
-
-return TRUE;
-}
-
 gamgi_bool gamgi_expat_import_plane (gamgi_plane *plane,
-char *filename, int fileline, gamgi_gml *gml)
+gamgi_object *parent, char *filename, int fileline, gamgi_gml *gml)
 {
 gamgi_cell *cell;
-gamgi_object *parent = plane->object.object;
 
-/*********************************
- * check crystallographic planes *
- *********************************/
+if (plane->reference != GAMGI_ENGINE_CELL) return TRUE;
 
-if (plane->reference == GAMGI_ENGINE_CELL)
+/*******************************************
+ * check crystallographic planes: polygons *
+ * may have a parent that is not a Cell!   *
+ *******************************************/
+
+if (parent->class != GAMGI_ENGINE_CELL)
   {
-  if (parent->class != GAMGI_ENGINE_CELL)
+  if (plane->type == FALSE) plane->type = GAMGI_PHYS_POLYGON;
+
+  if (plane->type != GAMGI_PHYS_POLYGON)
     return gamgi_io_error_child (filename, fileline, gml->ml.window);
 
-  cell = GAMGI_CAST_CELL parent;
-  if (cell->type == GAMGI_PHYS_PROJECTION)
-    {
-    /****************************************
-     * stereographic projection: show the   *
-     * pole and Wulff projection by default *
-     ****************************************/
+  if (plane->projection != NULL)
+    return gamgi_io_error_child (filename, fileline, gml->ml.window);
 
-    if (plane->type == GAMGI_PHYS_POLYGON)
-      return gamgi_io_error_child (filename, fileline, gml->ml.window);
-
-    if (plane->type == FALSE) plane->type = GAMGI_PHYS_POLE;
-
-    if (plane->projection == NULL)
-      plane->projection = GAMGI_PHYS_CELL_PROJECTION;
-    }
-  else
-    {
-    /****************************
-     * real plane: show polygon *
-     ****************************/
-
-    if (plane->type == GAMGI_PHYS_POLE || plane->type == GAMGI_PHYS_TRACE)
-      return gamgi_io_error_child (filename, fileline, gml->ml.window);
-
-    if (plane->type == FALSE) plane->type = GAMGI_PHYS_POLYGON;
-    }
+  return TRUE;
   }
-
-/***********************
- * check atomic planes *
- ***********************/
-
-if (plane->reference == GAMGI_ENGINE_ATOM)
+  
+cell = GAMGI_CAST_CELL parent;
+if (cell->type == GAMGI_PHYS_PROJECTION)
   {
+  /****************************************
+   * stereographic projection: show the   *
+   * pole and Wulff projection by default *
+   ****************************************/
+
+  if (plane->type == GAMGI_PHYS_POLYGON || plane->type == GAMGI_PHYS_VECTOR)
+    return gamgi_io_error_child (filename, fileline, gml->ml.window);
+
+  if (plane->projection == NULL)
+    plane->projection = GAMGI_PHYS_CELL_PROJECTION;
+
+  if (plane->type == FALSE) plane->type = GAMGI_PHYS_POLE;
+  }
+else
+  {
+  /*******************************************************************
+   * real plane: show polygon; reciprocal lattice vector: show cross *
+   *******************************************************************/
+
   if (plane->type == GAMGI_PHYS_POLE || plane->type == GAMGI_PHYS_TRACE)
     return gamgi_io_error_child (filename, fileline, gml->ml.window);
 
+  if (plane->projection != NULL)
+    return gamgi_io_error_child (filename, fileline, gml->ml.window);
+
+  if (plane->type == GAMGI_PHYS_VECTOR && cell->reciprocal == 0.0)
+    return gamgi_io_error_child (filename, fileline, gml->ml.window);
+
   if (plane->type == FALSE) plane->type = GAMGI_PHYS_POLYGON;
   }
 
@@ -1548,64 +1357,65 @@ return TRUE;
 }
 
 gamgi_bool gamgi_expat_import_direction (gamgi_direction *direction,
-char *filename, int fileline, gamgi_gml *gml)
+gamgi_object *parent, char *filename, int fileline, gamgi_gml *gml)
 {
 gamgi_cell *cell;
-gamgi_object *parent = direction->object.object;
 
 /*************************************
  * check crystallographic directions *
  *************************************/
 
-if (direction->reference == GAMGI_ENGINE_CELL)
+if (direction->reference != GAMGI_ENGINE_CELL) return TRUE;
+
+/********************************************
+ * check crystallographic directions: lines *
+ * may have a parent that is not a Cell!    *
+ ********************************************/
+
+if (parent->class != GAMGI_ENGINE_CELL)
   {
-  if (parent->class != GAMGI_ENGINE_CELL)
+  if (direction->type == FALSE) direction->type = GAMGI_PHYS_LINE;
+
+  if (direction->type != GAMGI_PHYS_LINE)
     return gamgi_io_error_child (filename, fileline, gml->ml.window);
 
-  cell = GAMGI_CAST_CELL parent;
-  if (cell->type == GAMGI_PHYS_PROJECTION)
-    {
-    /****************************************
-     * stereographic projection: show the   *
-     * pole and Wulff projection by default *
-     ****************************************/
+  if (direction->projection != NULL)
+    return gamgi_io_error_child (filename, fileline, gml->ml.window);
 
-    if (direction->type == GAMGI_PHYS_LINE)
-      return gamgi_io_error_child (filename, fileline, gml->ml.window);
-
-    if (gamgi_math_node_check (cell->lattice, direction->node[3]) == FALSE)
-      return gamgi_io_error_child (filename, fileline, gml->ml.window);
-
-    if (direction->type == FALSE) direction->type = GAMGI_PHYS_POLE;
-
-    if (direction->projection == NULL)
-      direction->projection = GAMGI_PHYS_CELL_PROJECTION;
-    }
-  else
-    {
-    /*****************************
-     * real direction: show line *
-     *****************************/
-
-    if (direction->type == GAMGI_PHYS_POLE || direction->type == GAMGI_PHYS_TRACE)
-      return gamgi_io_error_child (filename, fileline, gml->ml.window);
-
-    if (gamgi_math_node_check (cell->lattice, direction->node[3]) == FALSE)
-      return gamgi_io_error_child (filename, fileline, gml->ml.window);
-
-    if (direction->type == FALSE) direction->type = GAMGI_PHYS_LINE;
-    }
+  return TRUE;
   }
 
-/***************************
- * check atomic directions *
- ***************************/
+cell = GAMGI_CAST_CELL parent;
+if (gamgi_math_node_check (cell->lattice, direction->node[3]) == FALSE)
+  return gamgi_io_error_child (filename, fileline, gml->ml.window);
 
-if (direction->reference == GAMGI_ENGINE_ATOM)
+if (cell->type == GAMGI_PHYS_PROJECTION)
   {
+  /****************************************
+   * stereographic projection: show the   *
+   * pole and Wulff projection by default *
+   ****************************************/
+
+  if (direction->type == GAMGI_PHYS_LINE)
+    return gamgi_io_error_child (filename, fileline, gml->ml.window);
+
+  if (direction->projection == NULL)
+    direction->projection = GAMGI_PHYS_CELL_PROJECTION;
+
+  if (direction->type == FALSE) direction->type = GAMGI_PHYS_POLE;
+  }
+else
+  {
+  /*****************************
+   * real direction: show line *
+   *****************************/
+
   if (direction->type == GAMGI_PHYS_POLE || direction->type == GAMGI_PHYS_TRACE)
     return gamgi_io_error_child (filename, fileline, gml->ml.window);
 
+  if (direction->projection != NULL)
+    return gamgi_io_error_child (filename, fileline, gml->ml.window);
+
   if (direction->type == FALSE) direction->type = GAMGI_PHYS_LINE;
   }
 
@@ -1721,7 +1531,7 @@ gml->ref_file[gml->ref_used] = gml->ml.filename;
 gml->ref_used++;
 }
 
-gamgi_bool gamgi_expat_import_ref_apply (gamgi_gml *gml)
+gamgi_bool gamgi_expat_import_connect (gamgi_gml *gml)
 {
 gamgi_atom *atom1, *atom2;
 gamgi_bond *bond;
@@ -1845,21 +1655,13 @@ while (i < gml->ref_used)
 
     object->object = dlist_id1->data;
 
-    /**************************************
-     * check atomic directions and planes *
-     **************************************/
-
-    if (object->class == GAMGI_ENGINE_ATOM &&
-    gamgi_expat_import_atom (GAMGI_CAST_ATOM object,
-    filename, fileline, gml) == FALSE) return FALSE;
-
     /************************************************
      * check atomic and crystallographic directions *
      ************************************************/
 
     if (object->class == GAMGI_ENGINE_DIRECTION &&
     gamgi_expat_import_direction (GAMGI_CAST_DIRECTION object,
-    filename, fileline, gml) == FALSE) return FALSE;
+    object->object, filename, fileline, gml) == FALSE) return FALSE;
 
     /********************************************
      * check atomic and crystallographic planes *
@@ -1867,7 +1669,7 @@ while (i < gml->ref_used)
 
     if (object->class == GAMGI_ENGINE_PLANE &&
     gamgi_expat_import_plane (GAMGI_CAST_PLANE object,
-    filename, fileline, gml) == FALSE) return FALSE;
+    object->object, filename, fileline, gml) == FALSE) return FALSE;
 
     /******************************************************
      * each layer cannot have more than gamgi->max_lights *
@@ -1882,16 +1684,6 @@ while (i < gml->ref_used)
   i++;
   }
 
-/***************************************************
- * check if atomic planes have three atoms and     *
- * atomic directions have two atoms to define them *
- ***************************************************/
-
-if (gml->planes != 0)
-  return gamgi_io_error_plane (gml->ml.window);
-if (gml->directions != 0)
-  return gamgi_io_error_direction (gml->ml.window);
-
 return gml->ml.valid;
 }
 
@@ -2065,8 +1857,8 @@ if (valid == TRUE)
   gamgi_gtk_history_update (window->layer, 
   window->layer->undo, GAMGI_ENGINE_UNDO);
 
-  static_apply_object (gml);
-  static_apply_config ();
+  static_object (gml);
+  static_config (gml);
   }
 
 static_remove (gml, valid);
