@@ -17,20 +17,18 @@ static GtkWidget *static_atom (GtkWidget *dialog);
 
 static void static_end_atom (GtkWidget *dialog);
 
+static gamgi_enum static_class (gamgi_window *window);
+
 static void static_start_cell (gamgi_window *window);
 
 static void static_start_atom (gamgi_window *window);
 
 static void static_instance (GtkWidget *widget, void *data);
 
+static void static_start_scope (gamgi_window *window);
+
 static void static_start_position (gamgi_window *window);
 
-static void static_autonomy (GtkWidget *widget, void *data);
-
-static void static_reference (GtkWidget *widget, void *data);
-
-static void static_start_line (gamgi_window *window);
-
 static void static_start_projection (gamgi_window *window);
 
 static void static_nodes (GtkWidget *widget, void *data);
@@ -39,28 +37,19 @@ static void static_cell (GtkWidget *widget, void *data);
 
 static void static_vectors (GtkWidget *widget, void *data);
 
+static void static_reference (GtkWidget *widget, void *data);
+
 static void static_reset (gamgi_window *window);
 
-static void static_global (GtkWidget *widget, void *data);
+static void static_list (GtkWidget *widget, void *data);
 
-static gamgi_bool static_ok_cell (gamgi_direction *direction,
-gamgi_cell **cell, gamgi_window *window);
+static gamgi_bool static_grab (gamgi_window *window);
 
-static gamgi_bool static_ok_atoms (gamgi_direction *direction,
-gamgi_atom **atom1, gamgi_atom **atom2, gamgi_enum *in, gamgi_window *window);
+static gamgi_bool static_apply (gamgi_plane *plane, gamgi_window *window);
 
-static gamgi_bool static_ok_line (gamgi_cell *cell, int *uvw,
-gamgi_enum vectors, gamgi_enum *type, gamgi_projection *projection,
-gamgi_enum *autonomy, double *thickness, int *node, gamgi_window *window);
+static void static_ok_global (gamgi_window *window);
 
-static gamgi_bool static_ok_projection (gamgi_projection *projection,
-gamgi_enum *type, gamgi_enum *autonomy, gamgi_window *window);
-
-static gamgi_bool static_ok_position (gamgi_enum autonomy,
-double *euler, double *origin, gamgi_window *window);
-
-static gamgi_bool static_ok_view (gamgi_direction *direction, 
-gamgi_window *window);
+static void static_ok_local (gamgi_window *window);
 
 static void static_ok (GtkWidget *widget, void *data);
 
