@@ -56,7 +56,7 @@ else
   gtk_tree_selection_set_mode (selection, GTK_SELECTION_NONE);
 }
 
-void gamgi_gtk_select_method_pick (char *label, gamgi_window *window)
+void gamgi_gtk_select_method_direct (char *label, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *widget;
