@@ -20,9 +20,10 @@
 #include "gamgi_engine_create.h"
 #include "gamgi_engine_start.h"
 #include "gamgi_engine_link.h"
-#include "gamgi_engine_find.h"
 #include "gamgi_engine_remove.h"
 #include "gamgi_engine_dlist.h"
+#include "gamgi_engine_filter.h"
+#include "gamgi_engine_find.h"
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_gtk_history.h"
 #include "gamgi_gtk_object.h"
@@ -90,42 +91,6 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
 }
 
-static void static_autonomy (GtkWidget *widget, void *data)
-{
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *entry;
-GtkWidget *label;
-GtkWidget *combo;
-char token[GAMGI_ENGINE_TOKEN];
-int row;
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
-/************************
- * enable/disable scale *
- ************************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
-label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_scale");
-
-if (row == GAMGI_GTK_NONE - 1)
-  {
-  gtk_entry_set_text (GTK_ENTRY (entry), "");
-  gtk_widget_set_sensitive (entry, FALSE);
-  gtk_widget_set_sensitive (label, FALSE);
-  }
-else
-  {
-  gtk_widget_set_sensitive (entry, TRUE);
-  gtk_widget_set_sensitive (label, TRUE);
-  sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_SCALE);
-  gtk_entry_set_text (GTK_ENTRY (entry), token);
-  }
-
-}
-
 static void static_start_polytope (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
@@ -148,12 +113,27 @@ gtk_entry_set_text (GTK_ENTRY (entry), "");
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_local");
 gtk_button_clicked (GTK_BUTTON (button));
 
-/***************************
- * start polytope Autonomy *
- ***************************/
+/******************************
+ * structure, filter policies *
+ ******************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_GTK_NONE - 1);
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_structure");
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_CHEM_STRUCTURE - 1);
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_filter");
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_CHEM_FILTER - 1);
+
+/*******************************************
+ * start face tolerance: Visible, Coplanar *
+ *******************************************/
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_visible");
+sprintf (token, "%.*E", 2, GAMGI_CHEM_POLYTOPE_VISIBLE);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_coplanar");
+sprintf (token, "%.*E", 2, GAMGI_CHEM_POLYTOPE_COPLANAR);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
 
 /******************************
  * start Number of neighbours *
@@ -162,21 +142,9 @@ gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_GTK_NONE - 1);
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_number");
 gtk_button_clicked (GTK_BUTTON (button));
 
-/*******************************************
- * start face tolerance: Visible, Coplanar *
- *******************************************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_visible");
-sprintf (token, "%.*E", 2, GAMGI_CHEM_POLYTOPE_TOLERANCE_VISIBLE);
-gtk_entry_set_text (GTK_ENTRY (entry), token);
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_coplanar");
-sprintf (token, "%.*E", 2, GAMGI_CHEM_POLYTOPE_TOLERANCE_COPLANAR);
-gtk_entry_set_text (GTK_ENTRY (entry), token);
-
-/**********************
- * start Style, Color *
- **********************/
+/*****************************
+ * start Style, Color, Scale *
+ *****************************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_MESA_SOLID - 1);
@@ -184,6 +152,10 @@ gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_MESA_SOLID - 1);
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_color");
 gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
 static_color (button, window);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_SCALE);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
 }
 
 static void static_start_container (gamgi_window *window)
@@ -334,8 +306,10 @@ GtkWidget *button;
 gamgi_bool global;
 const char *name;
 char token[GAMGI_ENGINE_TOKEN];
+char string[GAMGI_ENGINE_STRING];
+char line[GAMGI_ENGINE_LINE] = "";
 double radius;
-int independent;
+int out[4];
 
 group->type = GAMGI_CHEM_POLYTOPE;
 
@@ -373,12 +347,15 @@ button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
   global = TRUE;
 
-/***********************************************
- * get Autonomy: the default is GAMGI_GTK_NONE *
- ***********************************************/
+/**********************************
+ * get structure, filter policies *
+ **********************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-group->autonomy = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_structure");
+group->structure = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_filter");
+group->filter = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 /****************************************************
  *     number of neighbours or maximum radius       *
@@ -389,7 +366,6 @@ group->autonomy = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 group->number = 0;
 radius = DBL_MAX;
-
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 
@@ -409,6 +385,7 @@ if (gamgi_io_token_check (name) == TRUE)
       gamgi_engine_remove_group (group);
       return;
       }
+
     radius = 0.0;
     }
   else
@@ -439,9 +416,11 @@ if (gamgi_io_token_check (name) == TRUE)
 group->element = -1;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_element");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gamgi_io_token_check (name) == TRUE && (gamgi_io_token_alpha_scan (name, 
-token, GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN) == FALSE || 
-gamgi_chem_atom_number (token, &group->element) == FALSE))
+
+if (gamgi_io_token_check (name) == TRUE &&
+(gamgi_io_token_alpha_scan (name, token, GAMGI_IO_TEXT,
+GAMGI_ENGINE_TOKEN) == FALSE || gamgi_chem_atom_number (token,
+&group->element) == FALSE))
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid neighbours element", window);
   gamgi_engine_remove_group (group);
@@ -455,7 +434,7 @@ gamgi_chem_atom_number (token, &group->element) == FALSE))
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_visible");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_double_scan (name, &group->visible,
-0.0, GAMGI_CHEM_POLYTOPE_TOLERANCE_VISIBLE_MAX) == FALSE)
+0.0, GAMGI_CHEM_POLYTOPE_VISIBLE_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid visible face tolerance", window);
   gamgi_engine_remove_group (group);
@@ -465,7 +444,7 @@ if (gamgi_io_token_double_scan (name, &group->visible,
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_coplanar");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_double_scan (name, &group->coplanar,
-0.0, GAMGI_CHEM_POLYTOPE_TOLERANCE_COPLANAR_MAX) == FALSE)
+0.0, GAMGI_CHEM_POLYTOPE_COPLANAR_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid coplanar face tolerance", window);
   gamgi_engine_remove_group (group);
@@ -539,8 +518,8 @@ else
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (group->autonomy != GAMGI_GTK_NONE && gamgi_io_token_double_scan (name,
-&group->object.scale, GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
+if (gamgi_io_token_double_scan (name, &group->object.scale,
+GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid scale data", window);
   gamgi_engine_remove_group (group);
@@ -576,6 +555,8 @@ gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO)
  *******************************/
 
 dlist = gamgi_engine_dlist_atom_object (window->focus, NULL);
+dlist = gamgi_engine_filter_atom (dlist, group->filter,
+GAMGI_ENGINE_GROUP, window->focus);
 
 /***********************************
  * create and initialize text      *
@@ -589,27 +570,69 @@ text = gamgi_gtk_dialog_text_create ();
  * number of independent atom positions that were found *
  ********************************************************/
 
-independent = gamgi_chem_polytope (dlist, group, atom, global, radius, TRUE, text);
-if (independent < 4 && global == FALSE) gamgi_engine_remove_group (group);
-if (independent < 2)
+if (gamgi_chem_polytope (dlist, group, atom, global,
+radius, group->structure, out, text) == FALSE)
   {
-  gamgi_gtk_dialog_message_create ("Error", 
-  "Insufficient number of valid neighbours", window);
+  gamgi_gtk_dialog_message_create ("Error",
+  "Insufficient number of neighbours", window);
   gtk_widget_destroy (text);
   return;
   }
-if (independent > 3)
+
+if (out[GAMGI_MATH_POLYTOPE_4] > 0)
   {
   dialog = gamgi_gtk_dialog_report_create (text,
   "Group Create Polytope", GAMGI_GTK_GROUP_CREATE_POLYTOPE, window);
   gtk_widget_show (dialog);
   }
+else
+  {
+  gtk_widget_destroy (text);
+  if (global == FALSE) gamgi_engine_remove_group (group);
+  }
+
+if (out[GAMGI_MATH_POLYTOPE_1] == 1)
+  {
+  sprintf (string, "Ignored one Group, ");
+  strcat (line, string);
+  }
+else if (out[GAMGI_MATH_POLYTOPE_1] > 1)
+  {
+  sprintf (string, "Ignored %d Groups, ", out[GAMGI_MATH_POLYTOPE_1]);
+  strcat (line, string);
+  }
+if (out[GAMGI_MATH_POLYTOPE_2] == 1)
+  {
+  sprintf (string, "Created one Direction, ");
+  strcat (line, string);
+  }
+else if (out[GAMGI_MATH_POLYTOPE_2] > 1)
+  {
+  sprintf (string, "Created %d Directions, ", out[GAMGI_MATH_POLYTOPE_2]);
+  strcat (line, string);
+  }
+if (out[GAMGI_MATH_POLYTOPE_3] == 1)
+  {
+  sprintf (string, "Created one Plane, ");
+  strcat (line, string);
+  }
+else if (out[GAMGI_MATH_POLYTOPE_3] > 1)
+  {
+  sprintf (string, "Created %d Planes, ", out[GAMGI_MATH_POLYTOPE_3]);
+  strcat (line, string);
+  }
+if (line[0] != '\0') strcat (line, "due to improper atom coordinates");
+
+if (out[GAMGI_MATH_POLYTOPE_1] + out[GAMGI_MATH_POLYTOPE_2] +
+out[GAMGI_MATH_POLYTOPE_3] > 0)
+  gamgi_gtk_dialog_message_create ("Warning", line, window);
 
 /************************
  * Redraw gl_area image *
  ************************/
 
-gtk_widget_queue_draw (window->area);
+if (out[GAMGI_MATH_POLYTOPE_2] + out[GAMGI_MATH_POLYTOPE_3] +
+out[GAMGI_MATH_POLYTOPE_4] > 0) gtk_widget_queue_draw (window->area);
 }
 
 /******************* internal function *****************
@@ -908,34 +931,65 @@ vbox_top = gtk_vbox_new (FALSE, 20);
 gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
-/********************************
- * Autonomy: All, Partial, None *
- ********************************/
+/******************************
+ * Structure, Filter policies *
+ ******************************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_end (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
+hbox_left = gtk_hbox_new (FALSE, 20);
+gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-label = gtk_label_new ("Autonomy");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 5);
+vbox_top_top = gtk_vbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top_top);
+
+label = gtk_label_new ("Structure");
+gtk_box_pack_start (GTK_BOX (vbox_top_top), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_signal_connect (combo, "changed",
-G_CALLBACK (static_autonomy), window);
-g_object_set_data (G_OBJECT (dialog), "combo_autonomy", combo);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "combo_structure", combo);
 gtk_widget_show (combo);
 
 store = gtk_list_store_new (1, G_TYPE_STRING);
 gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "All", -1);
+gtk_list_store_set (store, &iter, 0, "Copy", -1);
 gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "Partial", -1);
+gtk_list_store_set (store, &iter, 0, "Link", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "None", -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
+
+renderer = gtk_cell_renderer_text_new ();
+gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
+gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
+
+vbox_top_top = gtk_vbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top_top);
+
+label = gtk_label_new ("Filter");
+gtk_box_pack_start (GTK_BOX (vbox_top_top), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (vbox_top_top), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "combo_filter", combo);
+gtk_widget_show (combo);
+
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Class", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Child", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Identical", -1);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "None", -1);
 gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
@@ -1175,7 +1229,6 @@ gtk_widget_show (hbox_left);
 
 label = gtk_label_new ("Scale");
 gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "label_scale", label);
 gtk_widget_show (label);
 
 entry = gtk_entry_new ();
