@@ -30,6 +30,7 @@
 #include "gamgi_gtk_object.h"
 #include "gamgi_gtk_plane_create.h"
 #include "gamgi_gtk_plane_node.h"
+#include "gamgi_gtk_plane_list.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_math_vector.h"
 #include "gamgi_math_position.h"
@@ -725,7 +726,6 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
    ************************************/
 
   if (static_ok_cell (plane, &cell, window) == FALSE) return;
-
   if (cell->type == GAMGI_PHYS_PROJECTION)
     {
     if (static_ok_projection (plane, &pole, &trace, window) == FALSE) return;
@@ -796,6 +796,7 @@ if (plane->reference == GAMGI_ENGINE_ATOM)
   gamgi_math_position_plane_translation_set (plane, zero);
 
   gamgi_phys_plane_atoms (plane, atom1, atom2, atom3, dlist);
+  plane->vectors = GAMGI_PHYS_PLANE_VECTORS;
   }
 
 /************************   
@@ -1177,8 +1178,10 @@ G_CALLBACK (static_instance), window);
 g_object_set_data (G_OBJECT (dialog), "entry_l", entry);
 gtk_widget_show (entry);
 
-button = gtk_button_new_with_label (" Set ");
+button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
+g_signal_connect (button, "clicked",
+G_CALLBACK (gamgi_gtk_plane_list), window);
 g_object_set_data (G_OBJECT (dialog), "button_set", button);
 gtk_widget_show (button);
 
