@@ -13,11 +13,6 @@
  * internal functions *
  **********************
 
-static gamgi_bool static_find (gamgi_plane *plane, 
-gamgi_atom **atom1, gamgi_atom **atom2, gamgi_atom **atom3);
-
-static void static_remove (gamgi_plane *plane);
-
 static GtkWidget *static_atom (GtkWidget *dialog);
 
 static void static_end_atom (GtkWidget *dialog);
@@ -30,12 +25,6 @@ static void static_start_atom (gamgi_window *window);
 
 static void static_instance (GtkWidget *widget, void *data);
 
-static void static_start_position (gamgi_window *window);
-
-static void static_autonomy (GtkWidget *widget, void *data);
-
-static void static_reference (GtkWidget *widget, void *data);
-
 static void static_start_scope (gamgi_window *window);
 
 static void static_start_projection (gamgi_window *window);
@@ -46,29 +35,19 @@ static void static_cell (GtkWidget *widget, void *data);
 
 static void static_vectors (GtkWidget *widget, void *data);
 
+static void static_reference (GtkWidget *widget, void *data);
+
 static void static_reset (gamgi_window *window);
 
-static void static_global (GtkWidget *widget, void *data);
+static void static_list (GtkWidget *widget, void *data);
 
-static gamgi_bool static_ok_cell (gamgi_plane *plane, gamgi_cell **cell,
-gamgi_window *window);
+static gamgi_bool static_grab (gamgi_window *window);
 
-static gamgi_bool static_ok_atoms (gamgi_plane *plane, 
-gamgi_atom **atom1, gamgi_atom **atom2, gamgi_atom **atom3, 
-gamgi_window *window);
+static gamgi_bool static_apply (gamgi_plane *plane, gamgi_window *window);
 
-static gamgi_bool static_ok_scope (gamgi_cell *cell, int *hkl,
-gamgi_enum vectors, gamgi_enum *type, gamgi_projection *projection,
-gamgi_enum *autonomy, double *thickness, int *order, gamgi_window *window);
+static void static_ok_global (gamgi_window *window);
 
-static gamgi_bool static_ok_projection (gamgi_enum *autonomy,
-gamgi_projection *projection, gamgi_enum *type, gamgi_window *window);
-
-static gamgi_bool static_ok_position (gamgi_enum autonomy,
-double *euler, double *origin, gamgi_window *window);
-
-static gamgi_bool static_ok_view (float *red, float *green,
-float *blue, double *scale, gamgi_window *window);
+static void static_ok_local (gamgi_window *window);
 
 static void static_ok (GtkWidget *widget, void *data);
 
