@@ -39,9 +39,14 @@
 #include "gamgi_io_error.h"
 #include "gamgi_global_selection.h"
 
+enum { STATIC_NAME = 0, STATIC_CONTENTS,
+STATIC_TRANSLATION_X, STATIC_TRANSLATION_Y, STATIC_TRANSLATION_Z,
+STATIC_ROTATION_E1, STATIC_ROTATION_E2, STATIC_ROTATION_E3, STATIC_STYLE,
+STATIC_FONT, STATIC_RED, STATIC_GREEN, STATIC_BLUE, STATIC_SCALE };
+
 static struct {
 gamgi_bool local;
-gamgi_bool new[14];
+gamgi_bool new[STATIC_SCALE + 1];
 char name[GAMGI_ENGINE_TOKEN];
 char *contents;
 gamgi_enum style, font;
@@ -50,11 +55,6 @@ double translation[3], rotation[3];
 float red, green, blue;
 double scale; } cache;
 
-enum { STATIC_NAME = 0, STATIC_CONTENTS,
-STATIC_TRANSLATION_X, STATIC_TRANSLATION_Y, STATIC_TRANSLATION_Z,
-STATIC_ROTATION_E1, STATIC_ROTATION_E2, STATIC_ROTATION_E3, STATIC_STYLE,
-STATIC_FONT, STATIC_RED, STATIC_GREEN, STATIC_BLUE, STATIC_SCALE };
-
 static gamgi_enum static_font (gamgi_enum style, int offset)
 {
 /************************************************************
