@@ -148,8 +148,8 @@ gtk_tree_model_get (model, &new, 0, &name, -1);
 
 if (strcmp (name, "Pick") == 0)
   {
-  gamgi_gtk_select_method_pick ("widget_min", window);
-  gamgi_gtk_select_method_pick ("widget_max", window);
+  gamgi_gtk_select_method_direct ("widget_min", window);
+  gamgi_gtk_select_method_direct ("widget_max", window);
   }
 else
   {
@@ -351,10 +351,7 @@ else
  *   to Current and the model is updated   *
  *******************************************/
 
-if (gamgi->windows == NULL)
-  gamgi_global_selection_hide ("button_window");
-else
-  gamgi_global_selection_show ("button_window");
+gamgi_global_selection_update_windows (&gamgi->windows, "button_window");
 
 static_reset (window);
 }
