@@ -155,23 +155,21 @@ gamgi_math_matrix_inverse (matrix, inverse);
 gamgi_math_quaternion_from_matrix (inverse, quaternion);
 gamgi_mesa_rotate_object (object, quaternion, inverse, center);
 
-/***************************************************************
- * rotate parent foward, to update parent origin and center    *
- *                                                             *
- * backward and forward rotations are applied around an        * 
- * arbitrary point center, as these operations will change     *
- * the parent origin accordingly, which is then used in the    *
- * translation applied next to properly positionate the parent *
- ***************************************************************/
-
-gamgi_math_quaternion_from_matrix (rotation, quaternion);
-gamgi_mesa_rotate_object (object, quaternion, rotation, center);
-
 /****************************************************************
+ *   rotate parent foward, to update parent origin and center   *
+ *                                                              *
+ * backward and forward rotations are applied around an         * 
+ * arbitrary point center, as these operations will change      *
+ * the parent origin accordingly, which is then used in the     *
+ * translation applied next to properly positionate the parent  *
+ *                                                              *
  * rotation must be done before translation, to guarantee that  *
  * origin will have the defined origin coordinates. As rotation *
  * changes the origin, the translation then corrects the shift. *
  ****************************************************************/
+
+gamgi_math_quaternion_from_matrix (rotation, quaternion);
+gamgi_mesa_rotate_object (object, quaternion, rotation, center);
 }
 
 void gamgi_math_position_object_translation (gamgi_object *object, double *translation)
@@ -303,9 +301,6 @@ double *euler)
 {
 double matrix[9], inverse[9], relative[9], rotate[9];
 
-if (direction->autonomy == GAMGI_GTK_NONE)
-  { gamgi_math_vector_zero (euler); return; }
-
 /*****************************************************************
  * The direction euler angles show only the rotation             *
  * difference between the direction and the parent, while        *
@@ -342,9 +337,6 @@ double *relative)
 {
 double vector[3];
 
-if (direction->autonomy == GAMGI_GTK_NONE)
-  { gamgi_math_vector_zero (relative); return; }
-
 gamgi_math_position_translation (direction->object.object, vector);
 gamgi_math_vector_sub (direction->origin, vector, relative);
 }
@@ -396,9 +388,6 @@ void gamgi_math_position_plane_rotation_get (gamgi_plane *plane, double *euler)
 {
 double matrix[9], inverse[9], relative[9], rotate[9];
 
-if (plane->autonomy == GAMGI_GTK_NONE)
-  { gamgi_math_vector_zero (euler); return; }
-
 /***********************************************************
  * The plane euler angles show only the rotation           *
  * difference between the plane and the parent, while      *
@@ -434,9 +423,6 @@ void gamgi_math_position_plane_translation_get (gamgi_plane *plane, double *rela
 {
 double vector[3];
 
-if (plane->autonomy == GAMGI_GTK_NONE)
-  { gamgi_math_vector_zero (relative); return; }
-
 gamgi_math_position_translation (plane->object.object, vector);
 gamgi_math_vector_sub (plane->origin, vector, relative);
 }
@@ -488,9 +474,6 @@ void gamgi_math_position_group_rotation_get (gamgi_group *group, double *euler)
 {
 double matrix[9], inverse[9], relative[9], rotate[9];
 
-if (group->autonomy == GAMGI_GTK_NONE)
-  { gamgi_math_vector_zero (euler); return; }
-
 /***********************************************************
  * The group euler angles show only the rotation           *
  * difference between the group and the parent, while      *
@@ -526,9 +509,6 @@ void gamgi_math_position_group_translation_get (gamgi_group *group, double *rela
 {
 double vector[3];
 
-if (group->autonomy == GAMGI_GTK_NONE)
-  { gamgi_math_vector_zero (relative); return; }
-
 gamgi_math_position_translation (group->object.object, vector);
 gamgi_math_vector_sub (group->origin, vector, relative);
 }
