@@ -306,10 +306,6 @@ while (dlist != NULL)
 
 void gamgi_mesa_center_object (gamgi_object *object, double *sum, unsigned int *number)
 {
-gamgi_group *group;
-gamgi_plane *plane;
-gamgi_direction *direction;
-
 switch (object->class)
   {
   case GAMGI_ENGINE_TEXT:
@@ -329,27 +325,15 @@ switch (object->class)
   break;
 
   case GAMGI_ENGINE_DIRECTION:
-  direction = GAMGI_CAST_DIRECTION object;
-  if (direction->autonomy == GAMGI_GTK_NONE)
-    gamgi_mesa_center_object (object->object, sum, number);
-  else
-    gamgi_mesa_center_direction (direction, sum, number);
+  gamgi_mesa_center_direction (GAMGI_CAST_DIRECTION object, sum, number);
   break;
 
   case GAMGI_ENGINE_PLANE:
-  plane = GAMGI_CAST_PLANE object;
-  if (plane->autonomy == GAMGI_GTK_NONE)
-    gamgi_mesa_center_object (object->object, sum, number);
-  else
-    gamgi_mesa_center_plane (plane, sum, number);
+  gamgi_mesa_center_plane (GAMGI_CAST_PLANE object, sum, number);
   break;
 
   case GAMGI_ENGINE_GROUP:
-  group = GAMGI_CAST_GROUP object;
-  if (group->autonomy == GAMGI_GTK_NONE)
-    gamgi_mesa_center_object (object->object, sum, number);
-  else
-    gamgi_mesa_center_group (GAMGI_CAST_GROUP object, sum, number);
+  gamgi_mesa_center_group (GAMGI_CAST_GROUP object, sum, number);
   break;
 
   case GAMGI_ENGINE_MOLECULE:
