@@ -19,6 +19,40 @@
  * in Stereographic Projection and Reciprocal Lattice    *
  *********************************************************/
 
+static const char unsigned cross5[30] = {
+0x07, 0xc0,
+0x07, 0xc0,
+0x07, 0xc0,
+0x07, 0xc0,
+0x07, 0xc0,
+0xff, 0xfe,
+0xff, 0xfe,
+0xff, 0xfe,
+0xff, 0xfe,
+0xff, 0xfe,
+0x07, 0xc0,
+0x07, 0xc0,
+0x07, 0xc0,
+0x07, 0xc0,
+0x07, 0xc0 };
+
+static const char unsigned chess5[30] = {
+0xf8, 0x3e,
+0xf8, 0x3e,
+0xf8, 0x3e,
+0xf8, 0x3e,
+0xf8, 0x3e,
+0x07, 0xc0,
+0x07, 0xc0,
+0x07, 0xc0,
+0x07, 0xc0,
+0x07, 0xc0,
+0xf8, 0x3e,
+0xf8, 0x3e,
+0xf8, 0x3e,
+0xf8, 0x3e,
+0xf8, 0x3e };
+
 static const char unsigned cross4[24] = {
 0x0f, 0x00,
 0x0f, 0x00,
@@ -111,6 +145,9 @@ while (n_points-- > 0)
 
 void gamgi_mesa_render_points_cross (int n_points, double *points, int width)
 {
+if (width > 5) width = 5;
+if (width < 1) width = 1;
+
 switch (width)
   {
   case 1:
@@ -128,11 +165,18 @@ switch (width)
   case 4:
   static_mask (n_points, points, width, cross4);
   break;
+
+  case 5:
+  static_mask (n_points, points, width, cross5);
+  break;
   }
 }
 
 void gamgi_mesa_render_points_chess (int n_points, double *points, int width)
 {
+if (width > 5) width = 5;
+if (width < 1) width = 1;
+
 switch (width)
   {
   case 1:
@@ -150,6 +194,10 @@ switch (width)
   case 4:
   static_mask (n_points, points, width, chess4);
   break;
+
+  case 5:
+  static_mask (n_points, points, width, chess5);
+  break;
   }
 }
 
