@@ -110,7 +110,8 @@ void gamgi_mesa_start_direction (gamgi_direction *direction, gamgi_direction_cla
 {
 direction->vectors = GAMGI_PHYS_DIRECTION_VECTORS;
 direction->reference = GAMGI_ENGINE_CELL;
-direction->autonomy = GAMGI_GTK_NONE;
+direction->structure = GAMGI_CHEM_STRUCTURE;
+direction->filter = GAMGI_CHEM_FILTER;
 direction->thickness = GAMGI_CHEM_DIRECTION_THICKNESS;
 
 /*********
@@ -134,7 +135,8 @@ void gamgi_mesa_start_plane (gamgi_plane *plane, gamgi_plane_class *plane_class)
 {
 plane->vectors = GAMGI_PHYS_PLANE_VECTORS;
 plane->reference = GAMGI_ENGINE_CELL;
-plane->autonomy = GAMGI_GTK_NONE;
+plane->structure = GAMGI_CHEM_STRUCTURE;
+plane->filter = GAMGI_CHEM_FILTER;
 plane->thickness = GAMGI_CHEM_PLANE_THICKNESS;
 
 /*********
@@ -158,6 +160,16 @@ plane->blue = plane_class->blue;
 void gamgi_mesa_start_group (gamgi_group *group, gamgi_group_class *group_class)
 {
 strcpy (group->object.name, "Group");
+
+group->structure = GAMGI_CHEM_STRUCTURE;
+group->type = GAMGI_CHEM_CONTAINER;
+group->filter = GAMGI_CHEM_FILTER;
+group->visible = GAMGI_CHEM_POLYTOPE_VISIBLE;
+group->coplanar = GAMGI_CHEM_POLYTOPE_COPLANAR;
+
+group->red = GAMGI_MESA_GROUP_R;
+group->green = GAMGI_MESA_GROUP_G;
+group->blue = GAMGI_MESA_GROUP_B;
 }
 
 /******** external function ******
@@ -185,6 +197,7 @@ strcpy (molecule->object.name, "Molecule");
 void gamgi_mesa_start_cluster (gamgi_cluster *cluster, gamgi_cluster_class *cluster_class)
 {
 strcpy (cluster->object.name, "Cluster");
+cluster->type = GAMGI_CHEM_CONTAINER;
 }
 
 /***** external function *****
