@@ -18,6 +18,7 @@
 #include "gamgi_mesa_translate_out.h"
 #include "gamgi_mesa_draw.h"
 #include "gamgi_math_vector.h"
+#include "gamgi_global_selection.h"
 
 static void static_translate (gamgi_layer *layer, double *shift, double *translate)
 {
@@ -51,6 +52,11 @@ double *shift, double *translate)
 {
 gamgi_layer *layer;
 
+/***************************************************************
+ * translate must be recalculated only when layer changes, as  *
+ * shift remains the same throughout the translation operation *
+ ***************************************************************/
+
 layer = gamgi_engine_find_layer (object);
 if (layer != *layer_old)
   {
@@ -624,13 +630,21 @@ gamgi_text *text;
 gamgi_dlist *dlist;
 double translate[3];
 
+for (dlist = gamgi->texts; dlist != NULL; dlist = dlist->next)
+  gamgi_global_selection_text (GAMGI_CAST_TEXT dlist->data, TRUE);
+
 for (dlist = gamgi->texts; dlist != NULL; dlist = dlist->next)
   {
   text = GAMGI_CAST_TEXT dlist->data;
-
-  static_layer (GAMGI_CAST_OBJECT text, &layer, shift, translate);
-  gamgi_mesa_translate_text (text, translate);
+  if (text->mark == FALSE)
+    {
+    static_layer (GAMGI_CAST_OBJECT text, &layer, shift, translate);
+    gamgi_mesa_translate_text (text, translate);
+    }
   }
+
+for (dlist = gamgi->texts; dlist != NULL; dlist = dlist->next)
+  gamgi_global_selection_text (GAMGI_CAST_TEXT dlist->data, FALSE);
 }
 
 void gamgi_mesa_translate_orbital_list (double *shift)
@@ -723,13 +737,21 @@ gamgi_group *group;
 gamgi_dlist *dlist;
 double translate[3];
 
+for (dlist = gamgi->groups; dlist != NULL; dlist = dlist->next)
+  gamgi_global_selection_group (GAMGI_CAST_GROUP dlist->data, TRUE);
+
 for (dlist = gamgi->groups; dlist != NULL; dlist = dlist->next)
   {
   group = GAMGI_CAST_GROUP dlist->data;
-
-  static_layer (GAMGI_CAST_OBJECT group, &layer, shift, translate);
-  gamgi_mesa_translate_group (group, translate);
+  if (group->mark == FALSE)
+    {
+    static_layer (GAMGI_CAST_OBJECT group, &layer, shift, translate);
+    gamgi_mesa_translate_group (group, translate);
+    }
   }
+
+for (dlist = gamgi->groups; dlist != NULL; dlist = dlist->next)
+  gamgi_global_selection_group (GAMGI_CAST_GROUP dlist->data, FALSE);
 }
 
 void gamgi_mesa_translate_molecule_list (double *shift)
@@ -755,13 +777,21 @@ gamgi_cluster *cluster;
 gamgi_dlist *dlist;
 double translate[3];
 
+for (dlist = gamgi->clusters; dlist != NULL; dlist = dlist->next)
+  gamgi_global_selection_cluster (GAMGI_CAST_CLUSTER dlist->data, TRUE);
+
 for (dlist = gamgi->clusters; dlist != NULL; dlist = dlist->next)
   {
   cluster = GAMGI_CAST_CLUSTER dlist->data;
-
-  static_layer (GAMGI_CAST_OBJECT cluster, &layer, shift, translate);
-  gamgi_mesa_translate_cluster (cluster, translate);
+  if (cluster->mark == FALSE)
+    {
+    static_layer (GAMGI_CAST_OBJECT cluster, &layer, shift, translate);
+    gamgi_mesa_translate_cluster (cluster, translate);
+    }
   }
+
+for (dlist = gamgi->clusters; dlist != NULL; dlist = dlist->next)
+  gamgi_global_selection_cluster (GAMGI_CAST_CLUSTER dlist->data, FALSE);
 }
 
 void gamgi_mesa_translate_cell_list (double *shift)
@@ -835,13 +865,21 @@ gamgi_assembly *assembly;
 gamgi_dlist *dlist;
 double translate[3];
 
+for (dlist = gamgi->assemblys; dlist != NULL; dlist = dlist->next)
+  gamgi_global_selection_assembly (GAMGI_CAST_ASSEMBLY dlist->data, TRUE);
+
 for (dlist = gamgi->assemblys; dlist != NULL; dlist = dlist->next)
   {
   assembly = GAMGI_CAST_ASSEMBLY dlist->data;
-
-  static_layer (GAMGI_CAST_OBJECT assembly, &layer, shift, translate);
-  gamgi_mesa_translate_assembly (assembly, translate);
+  if (assembly->mark == FALSE)
+    {
+    static_layer (GAMGI_CAST_OBJECT assembly, &layer, shift, translate);
+    gamgi_mesa_translate_assembly (assembly, translate);
+    }
   }
+
+for (dlist = gamgi->assemblys; dlist != NULL; dlist = dlist->next)
+  gamgi_global_selection_assembly (GAMGI_CAST_ASSEMBLY dlist->data, FALSE);
 }
 
 void gamgi_mesa_translate_light_list (double *shift)
