@@ -800,7 +800,7 @@ else
    ********************************************/
 
   area = gamgi_math_polygon_area (darray0->offset, darray0->array);
-  if (area < GAMGI_MATH_PLANE_AREA)
+  if (area < GAMGI_MATH_DIRECTION_AREA)
     gamgi_phys_plane_default (r1, r2, r3, &inside, darray0);
 
   /**********************************************
