@@ -26,11 +26,11 @@ static void static_center (gamgi_direction *direction);
 static gamgi_darray *static_line (gamgi_direction *direction,
 double *position, double *normal, gamgi_dlist *dlist);
 
-static void static_link (gamgi_direction *direction,
-double *normal, gamgi_dlist *dlist);
+static void static_copy (gamgi_direction *direction, double *normal,
+gamgi_dlist *start);
 
-static void static_copy (gamgi_direction *direction,
-double *normal, gamgi_dlist *dlist);
+static void static_link (gamgi_direction *direction, double *normal,
+gamgi_dlist *start);
 
 static int static_order (int *hkl, gamgi_cell *cell, int step);
 
@@ -80,11 +80,7 @@ gamgi_atom *atom2, gamgi_window *window);
 gamgi_bool gamgi_phys_direction_reference (gamgi_direction *direction,
 gamgi_atom **atom1, gamgi_atom **atom2);
 
-gamgi_bool gamgi_phys_direction_compatible (gamgi_atom *atom1, 
-gamgi_atom *atom2);
-
-gamgi_bool gamgi_phys_direction_line (gamgi_atom *atom1,
-gamgi_atom *atom2);
+gamgi_bool gamgi_phys_direction_length (double *begin, double *end);
 
 gamgi_dlist *gamgi_phys_direction_reorder (gamgi_dlist *start,
 gamgi_atom *atom1, gamgi_atom *atom2);
@@ -93,7 +89,7 @@ void gamgi_phys_direction_atoms (gamgi_direction *direction,
 gamgi_atom *atom1, gamgi_atom *atom2, gamgi_dlist *dlist, gamgi_bool copy);
 
 void gamgi_phys_direction_polytope (int n_neighbours, gamgi_atom **neighbours,
-gamgi_enum autonomy, float red, float green, float blue, gamgi_object *parent,
+gamgi_enum structure, float red, float green, float blue, gamgi_object *parent,
 gamgi_atom *central);
 
 void gamgi_phys_direction_range (gamgi_direction *direction, 
@@ -105,6 +101,8 @@ void gamgi_phys_direction_node (gamgi_direction *direction, gamgi_cell *cell);
 void gamgi_phys_direction_projection (gamgi_direction *direction,
 gamgi_cell *cell, gamgi_enum pole, gamgi_enum trace);
 
+void gamgi_phys_direction_line (gamgi_direction *direction, double *points);
+
 /*************
  * Rationale *
  *************
