@@ -1568,38 +1568,6 @@ GAMGI_CAST_OBJECT atom3, GAMGI_CAST_OBJECT window->layer);
 return parent;
 }
 
-gamgi_bool gamgi_phys_plane_reference (gamgi_plane *plane,
-gamgi_atom **atom1, gamgi_atom **atom2, gamgi_atom **atom3)
-{
-gamgi_dlist *dlist = plane->atom_start;
-
-/************************************************
- * get the three atoms defining an atomic plane *
- ************************************************/
-
-*atom1 = NULL;
-*atom2 = NULL;
-*atom3 = NULL;
-
-if (dlist != NULL)
-  {
-  *atom1 = GAMGI_CAST_ATOM dlist->data;
-  dlist = dlist->next;
-  if (dlist != NULL)
-    {
-    *atom2 = GAMGI_CAST_ATOM dlist->data;
-    dlist = dlist->next;
-    if (dlist != NULL)
-      {
-      *atom3 = GAMGI_CAST_ATOM dlist->data;
-      return TRUE;
-      }
-    }
-  }
-
-return FALSE;
-}
-
 gamgi_bool gamgi_phys_plane_polygon (gamgi_atom *atom1,
 gamgi_atom *atom2, gamgi_atom *atom3)
 {
