@@ -75,7 +75,7 @@ double scale;
  * vector definition (the vectors must be primitive): *
  *          b1 = factor*(p2xp3)/(p1.p2xp3)            *
  *          b2 = factor*(p3xp1)/(p1.p2xp3)            *
- *          b3 = factor*(p1xp2)/(p1.p2xp3)            *
+ *          b3 = factor*(p1xp2)/(p1.p2xp3)          *
  ******************************************************/
 
 gamgi_math_vector_cross (p2, p3, b1);
@@ -315,6 +315,18 @@ gamgi_math_vector_sub (cell_old->origin, cell->origin, translate);
 gamgi_mesa_translate_cell (cell, translate);
 }
 
+void gamgi_phys_reciprocal_points (gamgi_plane *plane)
+{
+plane->points = (double *) malloc (3 * sizeof (double));
+gamgi_math_vector_copy (plane->origin, plane->points);
+plane->n_points = 1;
+
+plane->loops = (int *) malloc (2 * sizeof (int));
+plane->loops[0] = 1;
+plane->loops[1] = 0;
+plane->n_loops = 2;
+}
+
 gamgi_cell *gamgi_phys_reciprocal_primitive (gamgi_cell *cell_old,
 double factor, gamgi_window *window)
 {
@@ -347,6 +359,7 @@ cell->lattice = gamgi_phys_cell_primitive (cell_old->lattice);
 if (cell_old->lattice == GAMGI_PHYS_HEXAGONAL_R)
   cell->type = GAMGI_PHYS_PRIMITIVE;
 
+cell->reciprocal = factor;
 static_vectors (factor, cell->lattice, cell_old->a1,
 cell_old->a2, cell_old->a3, cell->p1, cell->p2, cell->p3);
 static_cell_increase (cell_old->lattice, cell);
@@ -447,6 +460,7 @@ strcpy (cell->object.name, "Reciprocal");
  ***********************************************/
 
 cell->lattice = gamgi_phys_reciprocal_lattice (cell_old->lattice);
+cell->reciprocal = factor;
 static_vectors (factor, cell->lattice, cell_old->p1,
 cell_old->p2, cell_old->p3, cell->p1, cell->p2, cell->p3);
 static_lattice (cell, transformation);
@@ -481,7 +495,7 @@ gamgi_math_matrix_vector (orientation, origin, translate);
 gamgi_mesa_translate_cell (cell, translate);
 
 if (planes == TRUE)
-  gamgi_phys_plane_reciprocal (cell, factor, transformation, orientation);
+  gamgi_phys_plane_reciprocal (cell, transformation, orientation);
 
 return cell;
 }
